@@ -22,6 +22,7 @@ from cdd.tests.mocks.docstrings import (
     docstring_google_tf_lambda_callback_str,
     docstring_google_tf_squared_hinge_str,
     docstring_header_and_return_str,
+    docstring_header_str,
     docstring_no_default_doc_str,
     docstring_numpydoc_only_doc_str,
     docstring_numpydoc_only_params_str,
@@ -196,7 +197,7 @@ class TestMarshallDocstring(TestCase):
         self.assertDictEqual(
             ir,
             {
-                "doc": "",
+                "doc": ir["doc"],
                 "name": None,
                 "params": OrderedDict(),
                 "returns": intermediate_repr_no_default_doc["returns"],
@@ -209,7 +210,7 @@ class TestMarshallDocstring(TestCase):
         Tests whether `docstring` produces `intermediate_repr_no_default_doc`
               from `docstring_numpydoc_only_doc_str`"""
         ir, returns = parse.docstring(
-            docstring_numpydoc_only_doc_str, return_tuple=True
+            docstring_numpydoc_only_doc_str.strip(), return_tuple=True
         )
         self.assertFalse(returns)
         self.assertDictEqual(
@@ -229,7 +230,9 @@ class TestMarshallDocstring(TestCase):
               from `docstring_google_str`
         """
         ir = parse_docstring(docstring_google_str)
-        self.assertDictEqual(ir, intermediate_repr_no_default_doc)
+        _intermediate_repr_no_default_doc = deepcopy(intermediate_repr_no_default_doc)
+        _intermediate_repr_no_default_doc["doc"] = docstring_header_str
+        self.assertDictEqual(ir, _intermediate_repr_no_default_doc)
 
     def test_from_docstring_google_tf_squared_hinge(self) -> None:
         """
@@ -280,6 +283,7 @@ class TestMarshallDocstring(TestCase):
                 docstring_google_tf_lambda_callback_str,
                 emit_default_doc=True,
                 infer_type=True,
+                parse_original_whitespace=True,
             ),
             docstring_google_tf_lambda_callback_ir,
         )
@@ -294,6 +298,7 @@ class TestMarshallDocstring(TestCase):
                 docstring_google_pytorch_lbfgs_str,
                 emit_default_doc=False,
                 infer_type=True,
+                parse_original_whitespace=False,
             ),
             docstring_google_pytorch_lbfgs_ir,
         )
